GeoTIFF Writer
==============

.. automodule:: polar2grid.writers.geotiff
    :noindex:

Command Line Arguments
----------------------

.. argparse::
    :module: polar2grid.writers.geotiff
    :func: add_writer_argument_groups
    :prog: |script| -r <reader> -w geotiff
    :passparser:
    :nodefaultconst:
